@@ -29,6 +29,7 @@ from wechaty_puppet import (    # type: ignore
     get_logger
 )
 
+from wechaty.exceptions import WechatyConfigurationError
 
 log = get_logger('Config')
 
@@ -44,6 +45,10 @@ DATA_PATH = os.path.realpath(
     ),
 )
 
+# http://jkorpela.fi/chars/spaces.html
+# String.fromCharCode(8197)
+AT_SEPARATOR = chr(0x2005)
+
 
 def global_exception_handler(exception: Exception) -> None:
     """
@@ -108,14 +113,14 @@ class Config:
             else DefaultSetting.default_protocol
 
         if token is None:
-            raise AttributeError('token can"t be None')
+            raise WechatyConfigurationError('token can"t be None')
 
         self.name = name
         self.debug = debug
         self.docker = docker
 
         if self.api_host is not None and not valid_api_host(self.api_host):
-            raise AttributeError('api host %s is not valid' % self.api_host)
+            raise WechatyConfigurationError('api host %s is not valid' % self.api_host)
 
 
 # export const CHATIE_OFFICIAL_ACCOUNT_ID = 'gh_051c89260e5d'
