@@ -45,6 +45,7 @@ from wechaty_puppet import (  # type: ignore
 )
 # from wechaty.utils import type_check
 from ..accessory import Accessory
+from ..config import AT_SEPARATOR
 
 if TYPE_CHECKING:
     from .contact import Contact
@@ -259,12 +260,28 @@ class Room(Accessory[RoomPayload]):
         """
         log.info('Room say <%s, %s>', some_thing, mention_ids)
 
+        if not some_thing:
+            log.error('can"t say nothing')
+            return None
+
         # we should import UrlLink type locally because of circular dependency
 
         from wechaty.user.url_link import UrlLink
         from wechaty.user.mini_program import MiniProgram
         from wechaty.user.contact import Contact
         if isinstance(some_thing, str):
+            if mention_ids:
+                mention_info = []
+                for mention_id in mention_ids:
+                    mention_contact: Contact = self.wechaty.Contact.load(mention_id)
+                    await mention_contact.ready()
+                    alias = await mention_contact.alias()
+                    name = mention_contact.name
+                    mention_info.append('@' + (alias or name))
+                
+                mention_text = AT_SEPARATOR.join(mention_info)
+                some_thing = mention_text + ' ' + some_thing
+
             msg_id = await self.puppet.message_send_text(
                 conversation_id=self.room_id, message=some_thing,
                 mention_ids=mention_ids
